@@ -8,10 +8,26 @@ summary.BIFIEdata <- function(object , ... ){
 	cat("'" )		
 	if( object$cdata ){ cat("\nCompact BIFIEdata") }
 	cat("\n\n" )	
-	cat( "Date of Analysis:" , paste( object$time[1] ) , "\n" )
+	cat( "Date of Analysis:" , paste( object$time[1] ) , "\n\n" )
+	
+	if ( ! object$NMI ){
+		cat("Multiply imputed dataset\n\n")
+					}
+	if ( object$NMI ){
+		cat("Nested multiply imputed dataset\n\n")
+		# object$Nimp <- object$Nimp_NMI
+					}
+					
     cat( "Number of persons =" , object$N , "\n" )    
-    cat( "Number of variables =" , object$Nvars , "\n" ) 	
-    cat( "Number of imputed datasets =" , object$Nimp , "\n" ) 
+    cat( "Number of variables =" , object$Nvars , "\n" )
+	if ( ! object$NMI){ 	
+		cat( "Number of imputed datasets =" , object$Nimp , "\n" ) 
+					}
+	if ( object$NMI){ 	
+		cat( "Number of imputed between-nest datasets =" , object$Nimp_NMI[1] , "\n" ) 
+		cat( "Number of imputed within-nest datasets =" , object$Nimp_NMI[2] , "\n" ) 
+					}
+					
     cat( "Number of Jackknife zones per dataset =" , object$RR , "\n" ) 
 	
 	fayfac <- object$fayfac
